{% extends "registration/subbase.html" %}
{% load i18n %}

{% block content %}{{ block.super }}
    <div class="topbox">
        <div class="notice-box info-notice">
            <h3>{% blocktrans %}You have completed your registration{% endblocktrans %}</h3>
            <p>{% blocktrans %}An activation email has been sent to your email account, you must use the activation link in this email to finally activate your account{% endblocktrans %}.</p>
        </div>
    </div>
{% endblock %}
