{% extends "registration/subbase.html" %}
{% load i18n crispy_forms_tags %}

{% block head_more_links %}
    <link rel="stylesheet" href="{{ STATIC_URL }}uni_form/uni-form.css" type="text/css" />
    <link rel="stylesheet" href="{{ STATIC_URL }}uni_form/default.uni-form.css" type="text/css" />
{% endblock %}
{% block head_more_js %}
    <script type="text/javascript" src="{{ STATIC_URL }}uni_form/uni-form.jquery.js"></script>
    {{ form.media }}
    <script language="JavaScript" type="text/javascript">
    //<![CDATA[
    $(document).ready(function() {
        $("form.uniForm").uniform();
    });
    //]]>
    </script>
{% endblock %}

{% block content %}{{ block.super }}

{% crispy form %}

{% endblock %}
